@@ -1,3 +1,5 @@
+import uuid
+
 from ajaxuploader.backends.local import LocalUploadBackend
 from ajaxuploader.views import AjaxFileUploader
 
@@ -14,6 +16,7 @@ class FileFormUploadBackend(LocalUploadBackend):
             uploaded_file='%s/%s' % (self.UPLOAD_DIR, filename),
             file_id=file_id,
             form_id=request.POST['form_id'],
+            original_filename=request.FILES['qqfile'].name,
         )
 
         field_name = request.POST.get('field_name', None)
@@ -21,8 +24,12 @@ class FileFormUploadBackend(LocalUploadBackend):
             values['field_name'] = field_name
 
         UploadedFile.objects.create(**values)
+
         return result
 
+    def update_filename(self, request, filename, *args, **kwargs):
+        return uuid.uuid4().hex
+
 
 class FileFormUploader(AjaxFileUploader):
     def __init__(self, backend=None, **kwargs):
